#
# spec file for package python-psutil
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           python-psutil
Version:        1.2.1
Release:        0.11.1
Summary:        A process utilities module for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://code.google.com/p/psutil/
Source:         psutil-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110 || 0%{?rhel} == 5
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif
%{!?py_ver:     %global py_ver     %(python -c "import sys; v=sys.version_info[:2]; print '%%d.%%d'%%v" 2>/dev/null || echo PYTHON-NOT-FOUND)}

%description
A graphical interface that lets you easily analyze and introspect unaltered running Python processes.

%prep
%setup -q -n psutil-%{version}
# Remove shebangs
sed -i "1d" psutil/{__init__.py,_compat.py,_psbsd.py,_pslinux.py,_psmswindows.py,_psosx.py,_psposix.py,error.py}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
# fails with "no module named psutil"
# python setup.py test

%files
%defattr(-,root,root,-)
%doc CREDITS examples HISTORY LICENSE README
%{python_sitearch}/psutil/
%{python_sitearch}/_psutil_*.so
%{python_sitearch}/psutil-%{version}-py%{py_ver}.egg-info

%changelog
* Wed Nov 27 2013 p.drouand@gmail.com
- Update to version 1.2.1
  * #348: [Windows XP] fixed "ImportError: DLL load failed" occurring
    on module import.
  * #425: [Solaris] crash on import due to failure at determining BOOT_TIME.
  * #443: [Linux] can't set CPU affinity with systems with more than 64 cores.
- Changes from version 1.2.0
  * #439: assume os.getpid() if no argument is passed to psutil.Process
    constructor.
  * #440: new psutil.wait_procs() utility function which waits for multiple
    processes to terminate.
  * #348: [Windows XP/Vista] fixed "ImportError: DLL load failed" occurring on
    module import.
- Changes from version 1.1.3
  * #442: [Linux] psutil won't compile on certain version of Linux because of
    missing prlimit(2) syscall.
- Changes from version 1.1.2
  * #442: [Linux] psutil won't compile on Debian 6.0 because of missing
    prlimit(2) syscall.
* Mon Oct 21 2013 dmueller@suse.com
- update to 1.1.1:
  * #410: tar.gz and windows binary files are now hosted on PYPI.
  * #412: [Linux] get/set process resource limits.
  * #415: [Windows] Process.get_children() is an order of magnitude faster.
  * #426: [Windows] Process.name is an order of magnitude faster.
  * #431: [UNIX] Process.name is slightly faster because it unnecessarily
    retrieved also process cmdline.
* Fri Jul 19 2013 dmueller@suse.com
- update to 1.0.1:
  * network_io_counters(pernic=True) no longer works as intended in 1.0.0.
* Thu Jul 11 2013 dmueller@suse.com
- update to 1.0.0:
  * Process.get_connections() 'status' strings are now constants.
  * test suite exits with non-zero on failure.  (patch by floppymaster)
  * extensively use unittest2 module in unit tests and provide
  workarounds if this is not installed on python < 2.7.
  * Process.get_memory_maps() may raise ValueError.
  * Process.get_connections() 'status' field is no longer a string but a constant
    object (psutil.CONN_*).
  * Process.get_connections() 'local_address' and 'remote_address' fields renamed
    to 'laddr' and 'raddr'.
  * psutil.network_io_counters() renamed to psutil.net_io_counters().
* Tue May  7 2013 michael@stroeder.com
- Update to upstream release 0.7.1:
  Many bug fixes, some new features and API changes
* Wed Jan  2 2013 toddrme2178@gmail.com
- Fix building on SLES
* Sat Oct  6 2012 os-dev@jacraig.com
- Update to 0.6.1:
  * process cmdline property now makes a better job at guessing the process
    executable from the cmdline.
  * process exe was resolved in case it was a symlink.
  * python 2.4 compatibility was broken.
  * process exe can now return an empty string instead of raising AccessDenied.
  * process exe is no longer resolved in case it's a symlink.
- Tons of changes from previous versions, please see HISTORY.
- Remove references to docs directory in spec file, as it no longer exists.
- Remove unnecessary shebangs from python scripts to quiet rpmlint.
* Fri May 25 2012 highwaystar.ru@gmail.com
- python3 package added
- minor spec improvement
* Tue Apr 24 2012 saschpe@suse.de
- It's not a noarch package
* Fri Mar 23 2012 saschpe@suse.de
- Spec file cleanup:
  * No need for setuptools here, distribute replaces it completely
  * Macro simplifcation
* Mon Mar 19 2012 cfarrell@suse.com
- First import
